@@ -35,10 +35,17 @@ Works with most (any?) Plantower I2C interfaced PM2.5 sensor.
 
 # imports
 import time
-from digitalio import Direction
+from digitalio import Direction, DigitalInOut
 from adafruit_bus_device.i2c_device import I2CDevice
 from . import PM25
 
+try:
+    # Used only for typing
+    import typing  # pylint: disable=unused-import
+    from busio import I2C
+except ImportError:
+    pass
+
 
 class PM25_I2C(PM25):
     """
@@ -77,7 +84,9 @@ class PM25_I2C(PM25):
 
     """
 
-    def __init__(self, i2c_bus, reset_pin=None, address=0x12):
+    def __init__(
+        self, i2c_bus: I2C, reset_pin: DigitalInOut = None, address: int = 0x12
+    ) -> None:
         if reset_pin:
             # Reset device
             reset_pin.direction = Direction.OUTPUT
@@ -98,7 +107,7 @@ class PM25_I2C(PM25):
             raise RuntimeError("Unable to find PM2.5 device")
         super().__init__()
 
-    def _read_into_buffer(self):
+    def _read_into_buffer(self) -> None:
         with self.i2c_device as i2c:
             try:
                 i2c.readinto(self._buffer)
